@@ -1,11 +1,11 @@
 """
 GUI progressbar decorator for iterators.
-Includes a default (x)range iterator printing to stderr.
+Includes a default `range` iterator printing to `stderr`.
 
 Usage:
-  >>> from tqdm.gui import trange[, tqdm]
-  >>> for i in trange(10): #same as: for i in tqdm(xrange(10))
-  ...     ...
+>>> from tqdm.gui import trange, tqdm
+>>> for i in trange(10):
+...     ...
 """
 # future division is important to divide integers and get as
 # a result precise floating numbers (instead of truncated int)
